# Connection 예제

이것은 Ezi-SERVO Plus-R 제품을 연결하고, 제품의 정보를 확인하는 예제입니다.

## 1. 연결

``` c++
BYTE nPortNo = 3;
DWORD dwBaudRate = 115200;

bool Connect(BYTE nPortNo, DWORD dwBaudRate)
{
	bool bSuccess = false;

	if (FAS_Connect(nPortNo, dwBaudRate) == false)
	{
		printf("Connection Fail!\n");
		bSuccess = false;
	}
	else
	{
		printf("Connection Success!\n");
		bSuccess = true;
	}

	return bSuccess;
}
```
FAS_Connect는 PortNo와 BaudRate를 통해 RS-485 통신 연결을 하는 함수입니다..

함수가 TRUE를 리턴하면 연결이 성공한 것입니다.

## 2. 제품 정보 확인
``` c++ 
bool CheckDriveInfo(BYTE nPortNo, BYTE iSlaveNo)
{
	BYTE byType = 0;
	char IpBuff[256] = "";
	int nBuffSize = 256;
	int nRtn;

	// Read Drive's information
	nRtn = FAS_GetSlaveInfo(nPortNo, iSlaveNo, &byType, IpBuff, nBuffSize);
	if (nRtn != FMM_OK)
	{
		printf("Function(FAS_GetSlaveInfo) was failed.\n");
		return false;
	}

	printf("Port No %d / Slave No %d : TYPE= %d, Version= %s\n", nPortNo, iSlaveNo, byType, IpBuff);

	return true;
}

```
연결 성공 후 제품의 정보를 확인하는 함수(FAS_GetSlaveInfo)를 사용하였습니다.
이 함수는 연결에 필요한 함수가 아닙니다. 연결 후 임의의 함수를 호출한 것입니다.

## 3. 연결 종료
``` c++
// Connection Close
FAS_Close(nPortNo);
```
FAS_Close()를 통해 연결을 해제할 수 있습니다.
